IsocurveItem — pyqtgraph 0.11.0rc0 documentation

# IsocurveItem

class `pyqtgraph.` `IsocurveItem`(data=None, level=0, pen='w', axisOrder=None)

  Bases: `GraphicsObject`

  Item displaying an isocurve of a 2D array. To align this item correctly with an ImageItem, call `isocurve.setParentItem(image)`.

  `__init__`(data=None, level=0, pen='w', axisOrder=None)

    Create a new isocurve item.

    Arguments: |
    data | A 2-dimensional ndarray. Can be initialized as None, and set later using `setData`
    level | The cutoff value at which to draw the isocurve.
    pen | The color of the curve item. Can be anything valid for `mkPen`
    axisOrder | May be either ‘row-major’ or ‘col-major’. By default this uses the `imageAxisOrder` global configuration option.

  `boundingRect`(self) → PySide2.QtCore.QRectF
  `paint`(self, painter: PySide2.QtGui.QPainter, option: PySide2.QtWidgets.QStyleOptionGraphicsItem, widget: typing.Union[PySide2.QtWidgets.QWidget, NoneType] = None)
  `setBrush`(*args, **kwargs)

    Set the brush used to draw the isocurve. Arguments can be any that are valid for `mkBrush`

  `setData`(data, level=None)

    Set the data/image to draw isocurves for.

    Arguments: |
    data | A 2-dimensional ndarray.
    level | The cutoff value at which to draw the curve. If level is not specified, the previously set level is used.

  `setLevel`(level)

    Set the level at which the isocurve is drawn.

  `setPen`(*args, **kwargs)

    Set the pen used to draw the isocurve. Arguments can be any that are valid for `mkPen`